@@ -73,7 +73,7 @@ BmpCreator::~BmpCreator()
 
 // -----------------------------------------------------------------------------
 
-void BmpCreator::Message( const String&, BYTE )
+void BmpCreator::Message( const String&, sal_uInt8 )
 {
 }
 
@@ -162,7 +162,7 @@ void BmpCreator::ImplCreate( const ::std::vector< DirEntry >& rInDirs,
             Message( aInfo );
 
             // create bit vector to hold flags for valid bitmaps
-            ::std::bit_vector   aValidBmpBitVector( aNameVector.size(), false );
+            ::std::vector<bool, std::allocator<bool> >   aValidBmpBitVector( aNameVector.size(), false );
             BitmapEx            aBmpEx;
 
             for( sal_uInt32 n = 0; n < aNameVector.size(); n++ )
@@ -330,7 +330,7 @@ void BmpCreator::Create( const String& rSRSName,
 {
     DirEntry	                aFileName( ImplGetSystemFileName( rSRSName ) ), aOutDir( ImplGetSystemFileName( rOutName ) );
     ::std::vector< DirEntry >   aInDirs;
-    BOOL		                bDone = FALSE;
+    sal_Bool		                bDone = sal_False;
 
     aFileName.ToAbs();
     aOutDir.ToAbs();
@@ -362,7 +362,7 @@ void BmpCreator::Create( const String& rSRSName,
     {
         String		aText;
         ByteString	aByteText;
-        BOOL		bLangDep = FALSE;
+        sal_Bool		bLangDep = sal_False;
 
         do
         {
@@ -390,7 +390,7 @@ void BmpCreator::Create( const String& rSRSName,
                     aByteText.Search( '[' ) != STRING_NOTFOUND &&
                     aByteText.Search( ']' ) != STRING_NOTFOUND )
                 {
-                    bLangDep = TRUE;
+                    bLangDep = sal_True;
                 }
 
                 if (!pSRS->ReadLine(aByteText))
@@ -402,13 +402,13 @@ void BmpCreator::Create( const String& rSRSName,
             // if image list is not language dependent, don't do anything for languages except german
             if( aText.Len() )
             {
-                bDone = TRUE;
+                bDone = sal_True;
                 ImplCreate( aInDirs, aOutDir, aName, rLang );
             }
 /*			else if( ( rLang.mnLangNum != 49 ) && !bLangDep )
             {
                 Message( String( RTL_CONSTASCII_USTRINGPARAM( "INFO: ImageList is not language dependent! Nothing to do for this language." ) ) );
-                bDone = TRUE;
+                bDone = sal_True;
             }*/
         }
         while ( aText.Len() );
