@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -56,13 +56,6 @@ namespace svt
 // .......................................................................
     namespace
     {
-        //..............................................................
-        sal_Bool isHiContrast(Window* _pWindow)
-        {
-            OSL_ENSURE(_pWindow,"Window must be not null!");
-            return _pWindow && _pWindow->GetSettings().GetStyleSettings().GetHighContrastMode(); 
-        }
-
         //..............................................................
         sal_uInt16 getRealGetFocusFlags( Window* _pWindow )
         {
@@ -137,7 +130,6 @@ namespace svt
     void EditBrowseBox::impl_construct()
     {
         m_aImpl = ::std::auto_ptr<EditBrowseBoxImpl>(new EditBrowseBoxImpl());
-        m_aImpl->m_bHiContrast = isHiContrast(&GetDataWindow());
 
         SetCompoundControl(sal_True);
         SetGridLineColor( Color( COL_LIGHTGRAY ) );
@@ -167,7 +159,7 @@ namespace svt
     {
         DBG_CTOR(EditBrowseBox,NULL);
 
-        impl_construct();		
+        impl_construct();
     }
 
     //==================================================================
@@ -262,7 +254,7 @@ namespace svt
         nPaintRow = nRow;
         return sal_True;
     }
-    
+
     //------------------------------------------------------------------------------
     IMPL_LINK(EditBrowseBox, StartEditHdl, void*, EMPTYARG)
     {
@@ -302,11 +294,9 @@ namespace svt
     //------------------------------------------------------------------------------
     Image EditBrowseBox::GetImage(RowStatus eStatus) const
     {
-        sal_Bool bHiContrast = isHiContrast(&GetDataWindow());
-        if ( !m_aStatusImages.GetImageCount() || (bHiContrast != m_aImpl->m_bHiContrast) )
+        if ( !m_aStatusImages.GetImageCount() )
         {
-            m_aImpl->m_bHiContrast = bHiContrast;
-            const_cast<EditBrowseBox*>(this)->m_aStatusImages = ImageList(SvtResId(bHiContrast ? RID_SVTOOLS_IMAGELIST_EDITBWSEBOX_H : RID_SVTOOLS_IMAGELIST_EDITBROWSEBOX));
+            const_cast<EditBrowseBox*>(this)->m_aStatusImages = ImageList( SvtResId( RID_SVTOOLS_IMAGELIST_EDITBROWSEBOX ) );
         }
 
         Image aImage;
@@ -511,7 +501,6 @@ namespace svt
 
         // we are about to leave the current cell. If there is a "this cell has been modified" notification
         // pending (asynchronously), this may be deadly -> do it synchronously
-        // 95826 - 2002-10-14 - fs@openoffice.org
         if ( nCellModifiedEvent )
         {
             Application::RemoveUserEvent( nCellModifiedEvent );
@@ -522,7 +511,6 @@ namespace svt
         if (0 == rEvt.GetColumnId())
         {	// it was the handle column. save the current cell content if necessary
             // (clicking on the handle column results in selecting the current row)
-            // 23.01.2001 - 82797 - FS
             if (IsEditing() && aController->IsModified())
                 SaveModified();
         }
@@ -622,7 +610,7 @@ namespace svt
             {
                 while ( GetSelectColumnCount( ) )
                     SelectColumnPos(
-                        sal::static_int_cast< USHORT >(FirstSelectedColumn()),
+                        sal::static_int_cast< sal_uInt16 >(FirstSelectedColumn()),
                         sal_False );
                 Select();
             }
@@ -830,7 +818,7 @@ namespace svt
         {
             ImplInitSettings( sal_True, sal_True, sal_True );
             Invalidate();
-        }		
+        }
     }
 
     //------------------------------------------------------------------------------
@@ -940,9 +928,9 @@ namespace svt
         {
             Window& rWindow = GetDataWindow();
             // don't paint too much
-            // update the status immediatly if possible				
+            // update the status immediatly if possible
             if ((nEditRow >= 0) && (GetBrowserFlags() & EBBF_NO_HANDLE_COLUMN_CONTENT) == 0)
-            {				
+            {
                 Rectangle aRect = GetFieldRectPixel(nEditRow, 0, sal_False );
                 // status cell should be painted if and only if text is displayed
                 // note: bPaintStatus is mutable, but Solaris has problems with assigning
@@ -950,16 +938,16 @@ namespace svt
                 pTHIS->bPaintStatus = static_cast< sal_Bool >
                     (( GetBrowserFlags() & EBBF_HANDLE_COLUMN_TEXT ) == EBBF_HANDLE_COLUMN_TEXT );
                 rWindow.Paint(aRect);
-                pTHIS->bPaintStatus = sal_True;			
-            }		
-            
+                pTHIS->bPaintStatus = sal_True;
+            }
+
             // don't paint during row change
-            rWindow.EnablePaint(sal_False);		
+            rWindow.EnablePaint(sal_False);
 
             // the last veto chance for derived classes
             if (!pTHIS->CursorMoving(nNewRow, nNewColId))
             {
-                pTHIS->InvalidateStatusCell(nEditRow);									
+                pTHIS->InvalidateStatusCell(nEditRow);
                 rWindow.EnablePaint(sal_True);
                 return sal_False;
             }
@@ -968,7 +956,7 @@ namespace svt
                 rWindow.EnablePaint(sal_True);
                 return sal_True;
             }
-        }			
+        }
         else
             return pTHIS->CursorMoving(nNewRow, nNewColId);
     }
@@ -1006,7 +994,7 @@ namespace svt
         if (nEditRow != nNewRow)
         {
             if ((GetBrowserFlags() & EBBF_NO_HANDLE_COLUMN_CONTENT) == 0)
-                InvalidateStatusCell(nNewRow);		
+                InvalidateStatusCell(nNewRow);
             nEditRow = nNewRow;
         }
         ActivateCell();
