@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
 *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -266,18 +267,14 @@ bool ATSLayout::LayoutText( ImplLayoutArgs& rArgs )
     if( (rArgs.mnFlags & SAL_LAYOUT_BIDI_STRONG) != 0 )
     {
         // control BiDi defaults
-        MacOSBOOL nLineDirTag = kATSULeftToRightBaseDirection;
+        BOOL nLineDirTag = kATSULeftToRightBaseDirection;
         if( (rArgs.mnFlags & SAL_LAYOUT_BIDI_RTL) != 0 )
             nLineDirTag = kATSURightToLeftBaseDirection;
         aTagAttrs[0] = kATSULineDirectionTag;
         aTagSizes[0] = sizeof( nLineDirTag );
         aTagValues[0] = &nLineDirTag;
         // set run-specific layout controls
-#if 0 // why don't line-controls work as reliably as layout-controls???
-        ATSUSetLineControls( maATSULayout, rArgs.mnMinCharPos, 1, aTagAttrs, aTagSizes, aTagValues );
-#else
         ATSUSetLayoutControls( maATSULayout, 1, aTagAttrs, aTagSizes, aTagValues );
-#endif
     }
 
     return true;
@@ -754,9 +751,10 @@ int ATSLayout::GetTextBreak( long nMaxWidth, long nCharExtra, int nFactor ) cons
     // initial measurement of text break position
     UniCharArrayOffset nBreakPos = mnMinCharPos;
     const ATSUTextMeasurement nATSUMaxWidth = Vcl2Fixed( nPixelWidth ); 
+    if( nATSUMaxWidth <= 0xFFFF ) // #i108584# avoid ATSU rejecting the parameter
+        return mnMinCharPos;      //           or do ATSUMaxWidth=0x10000;
     OSStatus eStatus = ATSUBreakLine( maATSULayout, mnMinCharPos,
         nATSUMaxWidth, false, &nBreakPos );
-
     if( (eStatus != noErr) && (eStatus != kATSULineBreakInWord) )
         return STRING_LEN;
 
@@ -781,7 +779,7 @@ int ATSLayout::GetTextBreak( long nMaxWidth, long nCharExtra, int nFactor ) cons
     if( eStatus != noErr )
         return nBreakPos;
     const ATSUTextMeasurement nATSURemWidth = nATSUMaxWidth - (nRight - nLeft);
-    if( nATSURemWidth <= 0 )
+    if( nATSURemWidth <= 0xFFFF ) // #i108584# avoid ATSU rejecting the parameter
         return nBreakPos;
     UniCharArrayOffset nBreakPosInWord = nBreakPos;
     eStatus = ATSUBreakLine( maATSULayout, nBreakPos, nATSURemWidth, false, &nBreakPosInWord );
@@ -1093,113 +1091,6 @@ void ATSLayout::InvalidateMeasurements()
 
 // =======================================================================
 
-#if 0
-// helper class to convert ATSUI outlines to VCL PolyPolygons
-class PolyArgs
-{
-public:
-                PolyArgs();
-                ~PolyArgs();
-
-    void		Init( PolyPolygon* pPolyPoly, long nXOffset, long nYOffset );
-    void		AddPoint( const Float32Point&, PolyFlags );
-    void		ClosePolygon();
-
-private:
-    PolyPolygon* mpPolyPoly;
-    long		mnXOffset, mnYOffset;
-
-    Point*		mpPointAry;
-    BYTE*		mpFlagAry;
-    USHORT		mnMaxPoints;
-
-    USHORT		mnPointCount;
-    USHORT		mnPolyCount;
-    bool		mbHasOffline;
-};
-
-// -----------------------------------------------------------------------
-
-PolyArgs::PolyArgs()
-:	mpPolyPoly(NULL),
-    mnPointCount(0),
-    mnPolyCount(0),
-    mbHasOffline(false)
-{
-    mnMaxPoints = 256;
-    mpPointAry	= new Point[ mnMaxPoints ];
-    mpFlagAry	= new BYTE [ mnMaxPoints ];
-}
-
-// -----------------------------------------------------------------------
-
-PolyArgs::~PolyArgs()
-{
-    delete[] mpFlagAry;
-    delete[] mpPointAry;
-}
-
-// -----------------------------------------------------------------------
-
-void PolyArgs::Init( PolyPolygon* pPolyPoly, long nXOffset, long nYOffset )
-{
-    mnXOffset = nXOffset;
-    mnYOffset = nYOffset;
-    mpPolyPoly = pPolyPoly;
-
-    mpPolyPoly->Clear();
-    mnPointCount = 0;
-    mnPolyCount  = 0;
-}
-
-// -----------------------------------------------------------------------
-
-void PolyArgs::AddPoint( const Float32Point& rPoint, PolyFlags eFlags )
-{
-    if( mnPointCount >= mnMaxPoints )
-    {
-        // resize if needed (TODO: use STL?)
-        mnMaxPoints *= 4;
-        Point* mpNewPoints = new Point[ mnMaxPoints ];
-        BYTE* mpNewFlags = new BYTE[ mnMaxPoints ];
-        for( int i = 0; i < mnPointCount; ++i )
-        {
-            mpNewPoints[ i ] = mpPointAry[ i ];
-            mpNewFlags[ i ] = mpFlagAry[ i ];
-        }
-        delete[] mpFlagAry;
-        delete[] mpPointAry;
-        mpPointAry = mpNewPoints;
-        mpFlagAry = mpNewFlags;
-    }
-
-    // convert to pixels and add startpoint offset
-    int nXPos = Float32ToInt( rPoint.x );
-    int nYPos = Float32ToInt( rPoint.y );
-    mpPointAry[ mnPointCount ] = Point( nXPos + mnXOffset, nYPos + mnYOffset );
-    // set point flags
-    mpFlagAry[ mnPointCount++ ]= eFlags;
-    mbHasOffline |= (eFlags != POLY_NORMAL);
-}
-
-// -----------------------------------------------------------------------
-
-void PolyArgs::ClosePolygon()
-{
-    if( !mnPolyCount++ )
-         return;
-
-    // append finished polygon
-    Polygon aPoly( mnPointCount, mpPointAry, (mbHasOffline ? mpFlagAry : NULL) );
-    mpPolyPoly->Insert( aPoly );
-
-    // prepare for new polygon
-    mnPointCount = 0;
-    mbHasOffline = false;
-}
-#endif
-// =======================================================================
-
 // glyph fallback is supported directly by Aqua
 // so methods used only by MultiSalLayout can be dummy implementated
 bool ATSLayout::GetGlyphOutlines( SalGraphics&, PolyPolyVector& rPPV ) const { return false; }
@@ -1262,3 +1153,4 @@ SalLayout* AquaSalGraphics::GetTextLayout( ImplLayoutArgs& rArgs, int nFallbackL
 
 // =======================================================================
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
