@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -37,14 +38,11 @@
 #include <vcl/image.h>
 #include <vcl/bitmapex.hxx>
 #include <vcl/pngread.hxx>
-#ifndef _SV_IMPIMAGETREE_H
 #include <vcl/impimagetree.hxx>
-#endif
-#ifndef _SV_RC_H
 #include <tools/rc.h>
-#endif
 #include <vcl/svapp.hxx>
 #include <vcl/bmpacc.hxx>
+#include <vcl/virdev.hxx>
 
 // ------------
 // - BitmapEx -
@@ -52,7 +50,7 @@
 
 BitmapEx::BitmapEx() :
         eTransparent( TRANSPARENT_NONE ),
-        bAlpha		( FALSE )
+        bAlpha		( sal_False )
 {
 }
 
@@ -70,7 +68,7 @@ BitmapEx::BitmapEx( const BitmapEx& rBitmapEx ) :
 
 BitmapEx::BitmapEx( const BitmapEx& rBitmapEx, Point aSrc, Size aSize ) :
         eTransparent( TRANSPARENT_NONE ),
-        bAlpha		( FALSE )
+        bAlpha		( sal_False )
 {
     if( rBitmapEx.IsEmpty() )
         return;
@@ -79,7 +77,7 @@ BitmapEx::BitmapEx( const BitmapEx& rBitmapEx, Point aSrc, Size aSize ) :
     aBitmapSize = aSize;
     if( rBitmapEx.IsAlpha() )
     {
-        bAlpha = TRUE;
+        bAlpha = sal_True;
         aMask = AlphaMask( aSize ).ImplGetBitmap();
     }
     else if( rBitmapEx.IsTransparent() )
@@ -94,7 +92,7 @@ BitmapEx::BitmapEx( const BitmapEx& rBitmapEx, Point aSrc, Size aSize ) :
 
 BitmapEx::BitmapEx( const ResId& rResId ) :
         eTransparent( TRANSPARENT_NONE ),
-        bAlpha		( FALSE )
+        bAlpha		( sal_False )
 {
     static ImplImageTreeSingletonRef	aImageTree;
     ResMgr* 							pResMgr = NULL;
@@ -106,11 +104,11 @@ BitmapEx::BitmapEx( const ResId& rResId ) :
     const String aFileName( pResMgr->ReadString() );
     ::rtl::OUString aCurrentSymbolsStyle = Application::GetSettings().GetStyleSettings().GetCurrentSymbolsStyleName();
     
-    if( !aImageTree->loadImage( aFileName, aCurrentSymbolsStyle, *this ) )
+    if( !aImageTree->loadImage( aFileName, aCurrentSymbolsStyle, *this, true ) )
     {
 #ifdef DBG_UTIL		
         ByteString aErrorStr( "BitmapEx::BitmapEx( const ResId& rResId ): could not load image <" );
-        DBG_ERROR( ( ( aErrorStr += ByteString( aFileName, RTL_TEXTENCODING_ASCII_US ) ) += '>' ).GetBuffer() );
+        OSL_FAIL( ( ( aErrorStr += ByteString( aFileName, RTL_TEXTENCODING_ASCII_US ) ) += '>' ).GetBuffer() );
 #endif
     }
 }
@@ -121,7 +119,7 @@ BitmapEx::BitmapEx( const Bitmap& rBmp ) :
         aBitmap		( rBmp ),
         aBitmapSize	( aBitmap.GetSizePixel() ),
         eTransparent( TRANSPARENT_NONE ),
-        bAlpha		( FALSE )
+        bAlpha		( sal_False )
 {
 }
 
@@ -132,7 +130,7 @@ BitmapEx::BitmapEx( const Bitmap& rBmp, const Bitmap& rMask ) :
         aMask			( rMask ),
         aBitmapSize		( aBitmap.GetSizePixel() ),
         eTransparent	( !rMask ? TRANSPARENT_NONE : TRANSPARENT_BITMAP ),
-        bAlpha			( FALSE )
+        bAlpha			( sal_False )
 {
     DBG_ASSERT( !rMask || rBmp.GetSizePixel() == rMask.GetSizePixel(),
                 "BitmapEx::BitmapEx(): size mismatch for bitmap and mask." );
@@ -152,7 +150,7 @@ BitmapEx::BitmapEx( const Bitmap& rBmp, const AlphaMask& rAlphaMask ) :
         aMask			( rAlphaMask.ImplGetBitmap() ),
         aBitmapSize		( aBitmap.GetSizePixel() ),
         eTransparent	( !rAlphaMask ? TRANSPARENT_NONE : TRANSPARENT_BITMAP ),
-        bAlpha			( !rAlphaMask ? FALSE : TRUE )
+        bAlpha			( !rAlphaMask ? sal_False : sal_True )
 {
     DBG_ASSERT( !rAlphaMask || rBmp.GetSizePixel() == rAlphaMask.GetSizePixel(),
                 "BitmapEx::BitmapEx(): size mismatch for bitmap and alpha mask." );
@@ -171,7 +169,7 @@ BitmapEx::BitmapEx( const Bitmap& rBmp, const Color& rTransparentColor ) :
         aBitmapSize			( aBitmap.GetSizePixel() ),
         aTransparentColor	( rTransparentColor ),
         eTransparent		( TRANSPARENT_BITMAP ),
-        bAlpha				( FALSE )
+        bAlpha				( sal_False )
 {
     aMask = aBitmap.CreateMask( aTransparentColor );
 
@@ -206,19 +204,19 @@ BitmapEx& BitmapEx::operator=( const BitmapEx& rBitmapEx )
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::operator==( const BitmapEx& rBitmapEx ) const
+sal_Bool BitmapEx::operator==( const BitmapEx& rBitmapEx ) const
 {
     if( eTransparent != rBitmapEx.eTransparent )
-        return FALSE;
+        return sal_False;
 
     if( aBitmap != rBitmapEx.aBitmap )
-        return FALSE;
+        return sal_False;
 
     if( aBitmapSize != rBitmapEx.aBitmapSize )
-        return FALSE;
+        return sal_False;
 
     if( eTransparent == TRANSPARENT_NONE )
-        return TRUE;
+        return sal_True;
 
     if( eTransparent == TRANSPARENT_COLOR )
         return aTransparentColor == rBitmapEx.aTransparentColor;
@@ -228,7 +226,7 @@ BOOL BitmapEx::operator==( const BitmapEx& rBitmapEx ) const
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::IsEqual( const BitmapEx& rBmpEx ) const
+sal_Bool BitmapEx::IsEqual( const BitmapEx& rBmpEx ) const
 {
     return( rBmpEx.eTransparent == eTransparent &&
             rBmpEx.bAlpha == bAlpha &&
@@ -238,7 +236,7 @@ BOOL BitmapEx::IsEqual( const BitmapEx& rBmpEx ) const
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::IsEmpty() const
+sal_Bool BitmapEx::IsEmpty() const
 {
     return( aBitmap.IsEmpty() && aMask.IsEmpty() );
 }
@@ -250,7 +248,7 @@ void BitmapEx::SetEmpty()
     aBitmap.SetEmpty();
     aMask.SetEmpty();
     eTransparent = TRANSPARENT_NONE;
-    bAlpha = FALSE;
+    bAlpha = sal_False;
 }
 
 // ------------------------------------------------------------------
@@ -262,14 +260,14 @@ void BitmapEx::Clear()
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::IsTransparent() const
+sal_Bool BitmapEx::IsTransparent() const
 {
     return( eTransparent != TRANSPARENT_NONE );
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::IsAlpha() const
+sal_Bool BitmapEx::IsAlpha() const
 {
     return( IsTransparent() && bAlpha );
 }
@@ -300,36 +298,6 @@ Bitmap BitmapEx::GetBitmap( const Color* pTransReplaceColor ) const
 
 // ------------------------------------------------------------------
 
-BitmapEx BitmapEx::GetColorTransformedBitmapEx( BmpColorMode eColorMode ) const
-{
-    BitmapEx aRet;
-    
-    if( BMP_COLOR_HIGHCONTRAST == eColorMode )
-    {
-        aRet = *this;
-        aRet.aBitmap = aBitmap.GetColorTransformedBitmap( eColorMode );
-    }
-    else if( BMP_COLOR_MONOCHROME_BLACK == eColorMode ||
-             BMP_COLOR_MONOCHROME_WHITE == eColorMode )
-    {
-        aRet = *this;
-        aRet.aBitmap = aRet.aBitmap.GetColorTransformedBitmap( eColorMode );
-        
-        if( !aRet.aMask.IsEmpty() )
-        {
-            aRet.aMask.CombineSimple( aRet.aBitmap, BMP_COMBINE_OR );
-            aRet.aBitmap.Erase( ( BMP_COLOR_MONOCHROME_BLACK == eColorMode ) ? COL_BLACK : COL_WHITE );
-
-            DBG_ASSERT( aRet.aBitmap.GetSizePixel() == aRet.aMask.GetSizePixel(),
-                        "BitmapEx::GetColorTransformedBitmapEx(): size mismatch for bitmap and alpha mask." );
-        }
-    }
-
-    return aRet;
-}
-
-// ------------------------------------------------------------------
-
 Bitmap BitmapEx::GetMask() const
 {
     Bitmap aRet( aMask );
@@ -356,9 +324,9 @@ AlphaMask BitmapEx::GetAlpha() const
 
 // ------------------------------------------------------------------
 
-ULONG BitmapEx::GetSizeBytes() const
+sal_uLong BitmapEx::GetSizeBytes() const
 {
-    ULONG nSizeBytes = aBitmap.GetSizeBytes();
+    sal_uLong nSizeBytes = aBitmap.GetSizeBytes();
 
     if( eTransparent == TRANSPARENT_BITMAP )
         nSizeBytes += aMask.GetSizeBytes();
@@ -368,7 +336,7 @@ ULONG BitmapEx::GetSizeBytes() const
 
 // ------------------------------------------------------------------
 
-ULONG BitmapEx::GetChecksum() const
+sal_uLong BitmapEx::GetChecksum() const
 {
     sal_uInt32	nCrc = aBitmap.GetChecksum();
     SVBT32		aBT32;
@@ -397,9 +365,9 @@ void BitmapEx::SetSizePixel( const Size& rNewSize )
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Invert()
+sal_Bool BitmapEx::Invert()
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !!aBitmap )
     {
@@ -414,9 +382,9 @@ BOOL BitmapEx::Invert()
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Mirror( ULONG nMirrorFlags )
+sal_Bool BitmapEx::Mirror( sal_uLong nMirrorFlags )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !!aBitmap )
     {
@@ -431,9 +399,9 @@ BOOL BitmapEx::Mirror( ULONG nMirrorFlags )
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Scale( const double& rScaleX, const double& rScaleY, ULONG nScaleFlag )
+sal_Bool BitmapEx::Scale( const double& rScaleX, const double& rScaleY, sal_uLong nScaleFlag )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !!aBitmap )
     {
@@ -453,9 +421,9 @@ BOOL BitmapEx::Scale( const double& rScaleX, const double& rScaleY, ULONG nScale
 
 // ------------------------------------------------------------------------
 
-BOOL BitmapEx::Scale( const Size& rNewSize, ULONG nScaleFlag )
+sal_Bool BitmapEx::Scale( const Size& rNewSize, sal_uLong nScaleFlag )
 {
-    BOOL bRet;
+    sal_Bool bRet;
 
     if( aBitmapSize.Width() && aBitmapSize.Height() )
     {
@@ -464,20 +432,20 @@ BOOL BitmapEx::Scale( const Size& rNewSize, ULONG nScaleFlag )
                       nScaleFlag );
     }
     else
-        bRet = TRUE;
+        bRet = sal_True;
 
     return bRet;
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Rotate( long nAngle10, const Color& rFillColor )
+sal_Bool BitmapEx::Rotate( long nAngle10, const Color& rFillColor )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !!aBitmap )
     {
-        const BOOL bTransRotate = ( Color( COL_TRANSPARENT ) == rFillColor );
+        const sal_Bool bTransRotate = ( Color( COL_TRANSPARENT ) == rFillColor );
 
         if( bTransRotate )
         {
@@ -517,9 +485,9 @@ BOOL BitmapEx::Rotate( long nAngle10, const Color& rFillColor )
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Crop( const Rectangle& rRectPixel )
+sal_Bool BitmapEx::Crop( const Rectangle& rRectPixel )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !!aBitmap )
     {
@@ -539,23 +507,23 @@ BOOL BitmapEx::Crop( const Rectangle& rRectPixel )
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Convert( BmpConversion eConversion )
+sal_Bool BitmapEx::Convert( BmpConversion eConversion )
 {
-    return( !!aBitmap ? aBitmap.Convert( eConversion ) : FALSE );
+    return( !!aBitmap ? aBitmap.Convert( eConversion ) : sal_False );
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::ReduceColors( USHORT nNewColorCount, BmpReduce eReduce )
+sal_Bool BitmapEx::ReduceColors( sal_uInt16 nNewColorCount, BmpReduce eReduce )
 {
-    return( !!aBitmap ? aBitmap.ReduceColors( nNewColorCount, eReduce ) : FALSE );
+    return( !!aBitmap ? aBitmap.ReduceColors( nNewColorCount, eReduce ) : sal_False );
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Expand( ULONG nDX, ULONG nDY, const Color* pInitColor, BOOL bExpandTransparent )
+sal_Bool BitmapEx::Expand( sal_uLong nDX, sal_uLong nDY, const Color* pInitColor, sal_Bool bExpandTransparent )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !!aBitmap )
     {
@@ -578,10 +546,10 @@ BOOL BitmapEx::Expand( ULONG nDX, ULONG nDY, const Color* pInitColor, BOOL bExpa
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::CopyPixel( const Rectangle& rRectDst, const Rectangle& rRectSrc,
+sal_Bool BitmapEx::CopyPixel( const Rectangle& rRectDst, const Rectangle& rRectSrc,
                           const BitmapEx* pBmpExSrc )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !pBmpExSrc || pBmpExSrc->IsEmpty() )
     {
@@ -612,7 +580,7 @@ BOOL BitmapEx::CopyPixel( const Rectangle& rRectDst, const Rectangle& rRectSrc,
 
                         aMask = pAlpha->ImplGetBitmap();
                         delete pAlpha;
-                        bAlpha = TRUE;
+                        bAlpha = sal_True;
                         aMask.CopyPixel( rRectDst, rRectSrc, &pBmpExSrc->aMask );
                     }
                     else
@@ -623,7 +591,7 @@ BOOL BitmapEx::CopyPixel( const Rectangle& rRectDst, const Rectangle& rRectSrc,
                         aMask = pAlpha->ImplGetBitmap();
                         delete pAlpha;
                         eTransparent = TRANSPARENT_BITMAP;
-                        bAlpha = TRUE;
+                        bAlpha = sal_True;
                         aMask.CopyPixel( rRectDst, rRectSrc, &pBmpExSrc->aMask );
                     }
                 }
@@ -667,9 +635,9 @@ BOOL BitmapEx::CopyPixel( const Rectangle& rRectDst, const Rectangle& rRectSrc,
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Erase( const Color& rFillColor )
+sal_Bool BitmapEx::Erase( const Color& rFillColor )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( !!aBitmap )
     {
@@ -696,41 +664,41 @@ BOOL BitmapEx::Erase( const Color& rFillColor )
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Dither( ULONG nDitherFlags )
+sal_Bool BitmapEx::Dither( sal_uLong nDitherFlags )
 {
-    return( !!aBitmap ? aBitmap.Dither( nDitherFlags ) : FALSE );
+    return( !!aBitmap ? aBitmap.Dither( nDitherFlags ) : sal_False );
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Replace( const Color& rSearchColor, const Color& rReplaceColor, ULONG nTol )
+sal_Bool BitmapEx::Replace( const Color& rSearchColor, const Color& rReplaceColor, sal_uLong nTol )
 {
-    return( !!aBitmap ? aBitmap.Replace( rSearchColor, rReplaceColor, nTol ) : FALSE );
+    return( !!aBitmap ? aBitmap.Replace( rSearchColor, rReplaceColor, nTol ) : sal_False );
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Replace( const Color* pSearchColors, const Color* pReplaceColors, ULONG nColorCount, const ULONG* pTols )
+sal_Bool BitmapEx::Replace( const Color* pSearchColors, const Color* pReplaceColors, sal_uLong nColorCount, const sal_uLong* pTols )
 {
-    return( !!aBitmap ? aBitmap.Replace( pSearchColors, pReplaceColors, nColorCount, (ULONG*) pTols ) : FALSE );
+    return( !!aBitmap ? aBitmap.Replace( pSearchColors, pReplaceColors, nColorCount, (sal_uLong*) pTols ) : sal_False );
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Adjust( short nLuminancePercent, short nContrastPercent,
+sal_Bool BitmapEx::Adjust( short nLuminancePercent, short nContrastPercent,
                        short nChannelRPercent, short nChannelGPercent, short nChannelBPercent,
-                       double fGamma, BOOL bInvert )
+                       double fGamma, sal_Bool bInvert )
 {
     return( !!aBitmap ? aBitmap.Adjust( nLuminancePercent, nContrastPercent,
                                         nChannelRPercent, nChannelGPercent, nChannelBPercent,
-                                        fGamma, bInvert ) : FALSE );
+                                        fGamma, bInvert ) : sal_False );
 }
 
 // ------------------------------------------------------------------
 
-BOOL BitmapEx::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam, const Link* pProgress )
+sal_Bool BitmapEx::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam, const Link* pProgress )
 {
-    return( !!aBitmap ? aBitmap.Filter( eFilter, pFilterParam, pProgress ) : FALSE );
+    return( !!aBitmap ? aBitmap.Filter( eFilter, pFilterParam, pProgress ) : sal_False );
 }
 
 // ------------------------------------------------------------------
@@ -757,6 +725,60 @@ void BitmapEx::Draw( OutputDevice* pOutDev,
     pOutDev->DrawBitmapEx( rDestPt, rDestSize, rSrcPtPixel, rSrcSizePixel, *this );
 }
 
+BitmapEx BitmapEx:: AutoScaleBitmap(BitmapEx & aBitmap, const long aStandardSize)
+{
+    Point aEmptyPoint(0,0);
+    sal_Int32 imgNewWidth = 0;
+    sal_Int32 imgNewHeight = 0;
+    double imgposX = 0;
+    double imgposY = 0;
+    BitmapEx  aRet = aBitmap;
+    double imgOldWidth = aRet.GetSizePixel().Width();
+    double imgOldHeight =aRet.GetSizePixel().Height();
+
+    Size aScaledSize;
+    if (imgOldWidth >= aStandardSize || imgOldHeight >= aStandardSize)
+    {
+        if (imgOldWidth >= imgOldHeight)
+        {
+            imgNewWidth = aStandardSize;
+            imgNewHeight = sal_Int32(imgOldHeight / (imgOldWidth / aStandardSize) + 0.5);
+            imgposX = 0;
+            imgposY = (aStandardSize - (imgOldHeight / (imgOldWidth / aStandardSize) + 0.5)) / 2 + 0.5;
+        }
+        else
+        {
+            imgNewHeight = aStandardSize;
+            imgNewWidth = sal_Int32(imgOldWidth / (imgOldHeight / aStandardSize) + 0.5);
+            imgposY = 0;
+            imgposX = (aStandardSize - (imgOldWidth / (imgOldHeight / aStandardSize) + 0.5)) / 2 + 0.5;
+        }
+
+        aScaledSize = Size( imgNewWidth, imgNewHeight );
+        aRet.Scale( aScaledSize, BMP_SCALE_INTERPOLATE );
+    }
+    else
+    {
+        imgposX = (aStandardSize - imgOldWidth) / 2 + 0.5;
+        imgposY = (aStandardSize - imgOldHeight) / 2 + 0.5;
+    }
+
+    Size aStdSize( aStandardSize, aStandardSize );
+    Rectangle aRect(aEmptyPoint, aStdSize );
+
+    VirtualDevice aVirDevice( *Application::GetDefaultDevice(), 0, 1 );
+    aVirDevice.SetOutputSizePixel( aStdSize );
+    aVirDevice.SetFillColor( COL_TRANSPARENT );
+    aVirDevice.SetLineColor( COL_TRANSPARENT );
+
+    //draw a rect into virDevice
+    aVirDevice.DrawRect( aRect );
+    Point aPointPixel( (long)imgposX, (long)imgposY );
+    aVirDevice.DrawBitmapEx( aPointPixel, aRet );
+    aRet = aVirDevice.GetBitmapEx( aEmptyPoint, aStdSize );
+
+    return aRet;
+}
 // ------------------------------------------------------------------
 
 sal_uInt8 BitmapEx::GetTransparency(sal_Int32 nX, sal_Int32 nY) const
@@ -835,9 +857,9 @@ SvStream& operator<<( SvStream& rOStm, const BitmapEx& rBitmapEx )
 {
     rBitmapEx.aBitmap.Write( rOStm );
 
-    rOStm << (UINT32) 0x25091962;
-    rOStm << (UINT32) 0xACB20201;
-    rOStm << (BYTE) rBitmapEx.eTransparent;
+    rOStm << (sal_uInt32) 0x25091962;
+    rOStm << (sal_uInt32) 0xACB20201;
+    rOStm << (sal_uInt8) rBitmapEx.eTransparent;
 
     if( rBitmapEx.eTransparent == TRANSPARENT_BITMAP )
         rBitmapEx.aMask.Write( rOStm );
@@ -857,9 +879,9 @@ SvStream& operator>>( SvStream& rIStm, BitmapEx& rBitmapEx )
 
     if( !rIStm.GetError() )
     {
-        const ULONG nStmPos = rIStm.Tell();
-        UINT32		nMagic1 = 0;
-        UINT32		nMagic2 = 0;
+        const sal_uLong nStmPos = rIStm.Tell();
+        sal_uInt32		nMagic1 = 0;
+        sal_uInt32		nMagic2 = 0;
 
         rIStm >> nMagic1 >> nMagic2;
 
@@ -871,11 +893,11 @@ SvStream& operator>>( SvStream& rIStm, BitmapEx& rBitmapEx )
         }
         else
         {
-            BYTE bTransparent = false;
+            sal_uInt8 bTransparent = false;
 
             rIStm >> bTransparent;
 
-            if( bTransparent == (BYTE) TRANSPARENT_BITMAP )
+            if( bTransparent == (sal_uInt8) TRANSPARENT_BITMAP )
             {
                 Bitmap aMask;
 
@@ -898,7 +920,7 @@ SvStream& operator>>( SvStream& rIStm, BitmapEx& rBitmapEx )
                 else
                     rBitmapEx = aBmp;
             }
-            else if( bTransparent == (BYTE) TRANSPARENT_COLOR )
+            else if( bTransparent == (sal_uInt8) TRANSPARENT_COLOR )
             {
                 Color aTransparentColor;
 
@@ -912,3 +934,5 @@ SvStream& operator>>( SvStream& rIStm, BitmapEx& rBitmapEx )
 
     return rIStm;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
